Stan Math Library: stan/math/prim/scal/err Directory Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

err Directory Reference

## Files
file | check_bounded.hpp [code]
file | check_consistent_size.hpp [code]
file | check_consistent_sizes.hpp [code]
file | check_equal.hpp [code]
file | check_finite.hpp [code]
file | check_greater.hpp [code]
file | check_greater_or_equal.hpp [code]
file | check_less.hpp [code]
file | check_less_or_equal.hpp [code]
file | check_nonnegative.hpp [code]
file | check_not_nan.hpp [code]
file | check_positive.hpp [code]
file | check_positive_finite.hpp [code]
file | check_positive_size.hpp [code]
file | check_size_match.hpp [code]
file | domain_error.hpp [code]
file | domain_error_vec.hpp [code]
file | invalid_argument.hpp [code]
file | invalid_argument_vec.hpp [code]
file | out_of_range.hpp [code]

[ Stan Home Page ] © 2011–2016, Stan Development Team.